<?php if(!defined('PURECLIENT_PATH')){die('Direct access not permitted');}
require_once(PURECLIENT_PATH.'/libraries/guzzle.phar');
use Guzzle\Http\Client;
		
class Person {

	public function __construct() {
    }
	
	function schedule_request() {
		/* if in dev mode, call on page load, else use cron */
		$options = get_option('pure_profiles_options');
		$dev = $options['pure_profiles_cron_dev_settings'];
		if ($dev =="yes") {
			add_action( 'plugins_loaded', array( $this, 'get_pure_persons' ) );
		} else {
			add_action('pure_profiles_request_api_event', array( $this, 'get_pure_persons' ));
		}
	}
	
	function get_pure_persons() {
		global $wpdb;
		$options = get_option('pure_profiles_options');
		$host = $options['pure_profiles_host_settings'];
		$username = $options['pure_profiles_username_settings'];
		$password = $options['pure_profiles_password_settings'];
		$person_ids = $options['pure_profiles_person_ids_settings'];

		if (($options == NULL) || ($person_ids == NULL)) return;
		
		// Create a client and provide a base URL
		$client = new Client($host);
		$request = $client->get('/ws/rest/persons?rendering=xml_long&personEmployeeIds.value='.$person_ids.'&window.size=100');
		$request->setAuth($username, $password);
		$request->getCurlOptions()->set(CURLOPT_SSL_VERIFYHOST, false);
		$request->getCurlOptions()->set(CURLOPT_SSL_VERIFYPEER, false);
		$request->getCurlOptions()->set(CURLOPT_CERTINFO, false);
		$request->getCurlOptions()->set(CURLOPT_TIMEOUT, 120);		
	
		$response = $request->send();
		
		$xml = $response->xml();
		$namespaces = $xml->getNamespaces(true);
		
		$core = $xml->children($namespaces['core']);
		
		/* if query is successful, clear out existing entries */
		if ($core->count > 0) {
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_person";
			$wpdb->query($truncate_sql);
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_person_information";
			$wpdb->query($truncate_sql);
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_organisation_association";
			$wpdb->query($truncate_sql);
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_staff_organisation_association";
			$wpdb->query($truncate_sql);			
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_project";
			$wpdb->query($truncate_sql);
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_project_person";
			$wpdb->query($truncate_sql);

			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_project_organisation";
			$wpdb->query($truncate_sql);			
			
			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_publication";
			$wpdb->query($truncate_sql);	

			$truncate_sql = "TRUNCATE TABLE ".$wpdb->prefix . "pure_profiles_publication_person";
			$wpdb->query($truncate_sql);				
		} else {
			return;
		}
		
		$retrieved = date("F j, Y, g:i a"); 
		
		for ($i=0; $i < $core->count; $i++) {
			$person = $core->result->content[$i]->children($namespaces['person']);
			$attributes = $core->result->content[$i]->attributes();
			$uuid = (string)$attributes['uuid'];	
			$employee_id = $person->employeeId;
			$name = $person->name->children($namespaces['core']);
			$call_name_first_name = "";
			if ($person->callName) {
				$call_name = $person->callName->children($namespaces['core']);
				$call_name_first_name = $call_name->firstName;
			}
			$stab = $core->result->content[$i]->children($namespaces['stab']);
			$title = $stab->title;
						
			/* get all photos */
			$photos_str = "";
			$photos_arr = array();
			if ($person->photos) {
				$photos = $person->photos->children($namespaces['core']);
				foreach ($photos->file as $phot) {
					$photos_arr[] = $phot->url;
				}
				$photos_str = implode(",", $photos_arr);
			}						
					
					
			/* insert persons into table */
			$table_name = $wpdb->prefix . "pure_profiles_person";
			$rows_affected = $wpdb->insert( $table_name, array( 
				'uuid' => $uuid, 
				'employeeid' => $employee_id, 				
				'firstname' => $name->firstName, 
				'lastname' => $name->lastName, 
				'callnamefirstname' => $call_name_first_name,
				'title' => $title, 
				'photos' => $photos_str,
				'retrieved' => $retrieved
			));
																						
			/* get all profile information */
			if ($person->profileInformation) {
				$profile_information = $person->profileInformation->children($namespaces['extensions']);
				$num_profile_information = count($profile_information->customField);
				for ($pi=0; $pi < $num_profile_information; $pi++) {
					$info_title = $profile_information->customField[$pi]->typeClassification->children($namespaces['core']);
					$the_info_title = addslashes($info_title->term->localizedString);
					$info_content = $profile_information->customField[$pi]->value->children($namespaces['core']);
					$the_info_content = addslashes($info_content->localizedString);
					
					
					/* insert profile information into table */
					$table_name = $wpdb->prefix . "pure_profiles_person_information";
					$rows_affected = $wpdb->insert( $table_name, array( 
						'personuuid' => $uuid, 
						'title' => $the_info_title, 
						'content' => $the_info_content, 
						'retrieved' => $retrieved
					));				
				}
			}

											
			/* get all organisation associations*/
			$organisation_associations = $person->organisationAssociations;
			$num_organisations = count($organisation_associations);
			
			for ($j=0; $j < $num_organisations; $j++) {
				$org_person = $person->organisationAssociations->organisationAssociation[$j]->children($namespaces['person']);
				$employment_type = $org_person->employmentType->children($namespaces['core']);
				$employement_type_attributes = $person->organisationAssociations->organisationAssociation[$j]->employmentType->attributes();
				$employment_type_id = (string)$employement_type_attributes['id'];
				$organisation = $person->organisationAssociations->organisationAssociation[$j]->organisation->children($namespaces['organisation']);
				$organisation_name = $organisation->name->children($namespaces['core']);
				$organisation_short_name = $organisation->shortName->children($namespaces['core']);
				$org_attributes = $person->organisationAssociations->organisationAssociation[$j]->organisation->attributes();
				$org_uuid = (string)$org_attributes['uuid'];	
				$org_type_classification_attributes = $organisation->typeClassification->attributes();
				$org_type_classification_id = $org_type_classification_attributes['id'];
				$org_type_classification = $organisation->typeClassification->children($namespaces['core']);
		
				/* insert organisation associations into table */
				$table_name = $wpdb->prefix . "pure_profiles_organisation_association";
				$rows_affected = $wpdb->insert( $table_name, array( 
					'personuuid' => $uuid, 
					'employeeid' => $employee_id, 
					'organisationuuid' => $org_uuid, 
					'organisationid' => $organisation->organisationId, 
					'organisationname' => $organisation_name, 
					'organisationshortname' => $organisation_short_name, 
					'organisationtypeclassificationid' => $org_type_classification_id, 
					'organisationtypeclassification' => $org_type_classification->term->localizedString, 
					'employmenttype' => $employment_type->term->localizedString, 
					'employmenttypeid' => $employment_type_id, 
					'retrieved' => $retrieved
				));

			}
			
			/* get all staff organisation associations*/
			$staff_organisation_associations = $stab->staffOrganisationAssociations;
			$num_staff_organisations = count($staff_organisation_associations);
			for ($k=0; $k < $num_staff_organisations; $k++) {
				$staff_org_stab = $stab->staffOrganisationAssociations->staffOrganisationAssociation[$k]->children($namespaces['stab']);
				$job_description = $staff_org_stab->jobDescription;
				$staff_org_person = $stab->staffOrganisationAssociations->staffOrganisationAssociation[$k]->children($namespaces['person']);
				$staff_org_person_org_attributes = $staff_org_person->organisation->attributes();
				$staff_org_uuid = $staff_org_person_org_attributes['uuid'];
				
				/* insert staff organisation associations into table */
				$table_name = $wpdb->prefix . "pure_profiles_staff_organisation_association";
				$rows_affected = $wpdb->insert( $table_name, array( 
					'personuuid' => $uuid, 
					'employeeid' => $employee_id, 
					'organisationuuid' => $staff_org_uuid, 
					'jobdescription' => $job_description, 
					'retrieved' => $retrieved
				));				
			}
			
			$publications = new Publication();
			$publications->get_publications($uuid);
			
			$projects = new Project();
			$projects->get_projects($uuid);
		}
		
	}
		
}